@@ -26,7 +26,7 @@
  * EMail: roseg@apsis.ch
  */
 
-static char *rcs_id = "$Id: svc.c,v 1.9 2005/06/01 15:01:54 roseg Rel $";
+static char *rcs_id = "$Id: svc.c,v 1.9 2005/06/01 15:01:54 roseg Rel roseg $";
 
 /*
  * $Log: svc.c,v $
@@ -217,7 +217,7 @@ logmsg(int priority, char *fmt, ...)
     if(print_log)
         printf("%s\n", buf);
     else
-        syslog(priority, "%s", buf);
+        syslog(log_facility | priority, "%s", buf);
 #endif
     return;
 }
@@ -249,7 +249,7 @@ va_dcl
     if(print_log)
         printf("%s\n", buf);
     else
-        syslog(priority, "%s", buf);
+        syslog(log_facility | priority, "%s", buf);
 #endif
     return;
 }
@@ -696,7 +696,7 @@ is_be(char *location, struct sockaddr_in *to_host, char *v_hostport, char *path,
 
     memset(&addr, 0, sizeof(addr));
     addr.sin_family = AF_INET;
-    if((he = gethostbyname(host)) == NULL)
+    if((he = gethostbyname(host)) == NULL || he->h_addr_list[0] == NULL)
         return 0;
     memcpy(&addr.sin_addr.s_addr, he->h_addr_list[0], sizeof(addr.sin_addr.s_addr));
     if(port != NULL)
